@@ -21,19 +21,19 @@
 #ifndef __GAIL_GNOME_DEBUG_H__
 #define __GAIL_GNOME_DEBUG_H__
 
-#include <glib/gmacros.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
-#ifdef GAIL_GNOME_DEBUG
+#ifdef G_ENABLE_DEBUG
 
 #include <stdio.h>
 
-#define dprintf(format...) fprintf (stderr, format)
+#define debug_printf(format...) fprintf (stderr, format)
 
 #else /* G_ENABLE_DEBUG */
 
-static inline void dprintf (const char *format, ...) { };
+static inline void debug_printf (const char *format, ...) { };
 
 #endif /* G_ENABLE_DEBUG */
 
