@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <atk/atkobjectfactory.h>
 #include <libspi/Accessibility.h>
 #include "panel-applet-atk-object.h"
