@@ -21,7 +21,7 @@
 #ifndef PANEL_APPLET_ATK_OBJECT_H_
 #define PANEL_APPLET_ATK_OBJECT_H_
 
-#include <gtk/gtkaccessible.h>
+#include <gtk/gtk.h>
 #include <panel-applet.h>
 
 G_BEGIN_DECLS
